.. :changelog:

Shiba : Python API for PriceMinister WebServices
================================================

Version 1.1.6
-------------

Released on August 10th 2016

- Updated the webservices versions

Version 1.1.5
-------------

Released on July 21st 2016

- Python 3 support
